Trees and Tree Algorithms
:::::::::::::::::::::::::

.. toctree::
    :caption: Trees and Tree Algorithms
    :maxdepth: 2

    Objectives.rst
    ExamplesofTrees.rst
    VocabularyandDefinitions.rst
    Implementation.rst
    ListofListsRepresentation.rst
    NodesandReferences.rst
    ParseTree.rst
    TreeTraversals.rst
    PriorityQueueswithBinaryHeaps.rst
    BinaryHeapOperations.rst
    BinaryHeapImplementation.rst
    BinarySearchTrees.rst
    SearchTreeOperations.rst
    SearchTreeImplementation.rst
    SearchTreeAnalysis.rst
    BalancedBinarySearchTrees.rst
    AVLTreePerformance.rst
    AVLTreeImplementation.rst
    SummaryofMapADTImplementations.rst
    Summary.rst
    KeyTerms.rst
    Exercises.rst
